==> nextcloud-13.0.2.tar.bz2: nextcloud/core/l10n/ar.js <==
OC.L10N.register(
    "core",
    {
    "Please select a file." : "يرجى تحديد ملف.",
    "File is too big" : "الملف كبير جدا",
    "The selected file is not an image." : "الملف المحدد ليس صورة ",
    "The selected file cannot be read." : "الملف المحدد لا يمكن قرأته",
    "Invalid file provided" : "تم تقديم ملف غير صالح",
    "No image or file provided" : "لم يتم توفير صورة أو ملف",
    "Unknown filetype" : "نوع الملف غير معروف",
    "Invalid image" : "الصورة غير صالحة",
    "An error occurred. Please contact your admin." : "حدث خطأ، يرجى مراجعة المسؤول.",
    "No temporary profile picture available, try again" : "لا تتوفر صورة ملف شخصي مؤقتة، حاول مرة أخرى",
    "Crop is not square" : "القص ليس مربعا",
    "Password reset is disabled" : "تم تعطيل إعادة تعيين كلمة المرور",
    "%s password reset" : "%s إعادة تعيين كلمة مرور ",
    "Password reset" : "إعادة تعيين كلمة مرور",
    "Reset your password" : "أعد تعيين كلمة المرور",
    "Couldn't send reset email. Please contact your administrator." : "تعذر إرسال البريد الإلكتروني لإعادة التعيين. يرجى مراجعة المسؤول.",
    "Couldn't send reset email. Please make sure your username is correct." : "تعذر إرسال البريد الإلكتروني لإعادة التعيين. الرجاء التأكد من صحة اسم المستخدم.",
    "Preparing update" : "جارٍ تهيئة التحديث",
    "[%d / %d]: %s" : "[%d/%d]: %s",
    "Repair error: " : "خطأ في الإصلاح:",
    "Turned on maintenance mode" : "تشغيل وضع الصيانة.",
    "Turned off maintenance mode" : "تعطيل وضع الصيانة.",
    "Updated database" : "قاعدة بيانات محدثة",
    "Checking updates of apps" : "التحقق من تحديثات التطبيقات",
    "Checking for update of app \"%s\" in appstore" : "التحقق من تحديثات التطبيقات \"%s\" في متجر التطبيقات",
    "Update app \"%s\" from appstore" : "قم بتحديث التطبيق \"%s\" عن طريق متجر التطبيقات",
    "Checked for update of app \"%s\" in appstore" : "التحقق من تحديثات التطبيقات \" %s \" في متجر التطبيقات",
    "Already up to date" : "محدّثة مسبقاً",
    "Search contacts …" : "البحث عن مراسلين …",
    "Show all contacts …" : "إظهار كافة المراسلين …",
    "Loading your contacts …" : "تحميل جهات الاتصال",
    "Looking for {term} …" : "جاري البحث عن {term}",
    "No action available" : "لا يتوفر أي إجراء",
    "Error fetching contact actions" : "حدث خطأ أثناء جلب إجراءات جهات الاتصال",
    "Settings" : "الضبط",
    "Connection to server lost" : "تم فقد الاتصال بالخادم",
    "Saving..." : "جاري الحفظ...",
    "Dismiss" : "تجاهل",
    "This action requires you to confirm your password" : "يتطلب هذا الإجراء منك تأكيد كلمة المرور",
    "Authentication required" : "المصادقة مطلوبة",
    "Password" : "كلمة المرور",
    "Cancel" : "الغاء",
    "Confirm" : "تأكيد",
    "Failed to authenticate, try again" : "أخفق المصادقة، أعد المحاولة",
    "seconds ago" : "منذ ثواني",
    "Logging in …" : "تسجيل الدخول …",
    "I know what I'm doing" : "أعرف ماذا أفعل",
    "Password can not be changed. Please contact your administrator." : "كلمة المرور لا يمكن تغييرها. فضلاً تحدث مع المسؤول",
    "Reset password" : "تعديل كلمة السر",
    "Sending email …" : "جارٍ إرسال البريد …",
    "No" : "لا",
    "Yes" : "نعم",
    "No files in here" : "لا توجد ملفات هنا",
    "Choose" : "اختيار",
    "Copy" : "نسخ",
    "Move" : "نقل",
    "OK" : "موافق",
    "read-only" : "قراءة فقط",
    "New Files" : "ملفات جديدة",
    "Already existing files" : "المفات موجودة مسبقاً",
    "Which files do you want to keep?" : "ماهي الملفات التي ترغب في إبقاءها ؟",
    "If you select both versions, the copied file will have a number added to its name." : "عند إختيار كلا النسختين. المف المنسوخ سيحتوي على رقم في إسمه.",
    "Continue" : "المتابعة",
    "(all selected)" : "(إختيار الكل)",
    "Pending" : "معلّق",
    "Copy to {folder}" : "أنسخ إلى {folder}",
    "Move to {folder}" : "النقل إلى {folder}",
    "Very weak password" : "كلمة السر ضعيفة جدا",
    "Weak password" : "كلمة السر ضعيفة",
    "Good password" : "كلمة السر جيدة",
    "Strong password" : "كلمة السر قوية",
    "Shared" : "مشارك",
    "Shared with" : "تمت مشاركته مع",
    "Shared by" : "شاركه",
    "Error setting expiration date" : "حصل خطأ عند عملية تعيين تاريخ إنتهاء الصلاحية",
    "Set expiration date" : "تعيين تاريخ إنتهاء الصلاحية",
    "Expiration" : "إنتهاء",
    "Expiration date" : "تاريخ إنتهاء الصلاحية",
    "Choose a password for the public link" : "اختر كلمة مرور للرابط العام",
    "Choose a password for the public link or press the \"Enter\" key" : "اختر كلمة مرور للرابط العام أو إضغط على زر \"Enter\"",
    "Copied!" : "تم نسخه !",
    "Not supported!" : "غير مدعوم !",
    "Press ⌘-C to copy." : "إضغط C-⌘ للنسخ.",
    "Press Ctrl-C to copy." : "للنسخ إضغط على CTRL+C.",
    "Resharing is not allowed" : "لا يسمح بعملية إعادة المشاركة",
    "Share to {name}" : "تمت مشاركته مع {name}",
    "Share link" : "شارك الرابط",
    "Link" : "الرابط",
    "Password protect" : "حماية كلمة السر",
    "Allow editing" : "السماح بالتعديلات",
    "Email link to person" : "ارسل الرابط بالبريد الى صديق",
    "Send" : "أرسل",
    "Allow upload and editing" : "السماح بالرفع و التعديل",
    "Read only" : "القراءة فقط",
    "Shared with you and the group {group} by {owner}" : "شورك معك ومع المجموعة {group} من قبل {owner}",
    "Shared with you by {owner}" : "شورك معك من قبل {owner}",
    "Choose a password for the mail share" : "إختر كلمة سرية للمشاركة عبر البريد الإلكتروني",
    "group" : "مجموعة",
    "remote" : "عن بعد",
    "email" : "البريد الإلكتروني",
    "shared by {sharer}" : "شارَكه {sharer}",
    "Unshare" : "إلغاء مشاركة",
    "Can reshare" : "يمكنه إعادة المشاركة",
    "Can edit" : "يمكنه التغيير",
    "Can create" : "يمكنه الإنشاء",
    "Can change" : "يمكنه تعديله",
    "Can delete" : "يمكنه الحذف",
    "Access control" : "مراقبة النفاذ",
    "Could not unshare" : "لا يمكن إلغاء المشاركة",
    "Error while sharing" : "حصل خطأ عند عملية المشاركة",
    "An error occurred. Please try again" : "طرأ هناك خطأ. الرجاء إعادة المحاولة",
    "{sharee} (group)" : "{sharee} (group)",
    "{sharee} (remote)" : "{sharee} (remote)",
    "{sharee} (email)" : "{sharee} (email)",
    "Share" : "شارك",
    "Name or email address..." : "الإسم أو عنوان البريد الإلكتروني …",
    "Name or federated cloud ID..." : "الإسم أو معرّف السحابة المتحدة …",
    "Name..." : "التسمية …",
    "Error" : "خطأ",
    "restricted" : "مُقيَّد",
    "invisible" : "مخفي",
    "({scope})" : "({scope})",
    "Delete" : "إلغاء",
    "Rename" : "إعادة التسمية",
    "No tags found" : "لم يُعثَر على أي وسم",
    "unknown text" : "النص غير معروف",
    "Hello world!" : "مرحبا بالعالم!",
    "sunny" : "مشمس",
    "Hello {name}" : "مرحبا {name}",
    "new" : "جديد",
    "_download %n file_::_download %n files_" : ["تنزيل %n ملف","تنزيل ملف واحد","تنزيل ملفين","تنزيل %n ملفات","تنزيل %n ملفات","تنزيل %n ملفات"],
    "Update to {version}" : "التحديث إلى {version}",
    "An error occurred." : "طرأ هناك خطأ.",
    "Please reload the page." : "رجاء أعد تحميل الصفحة.",
    "Continue to Nextcloud" : "المواصلة إلى ناكست كلاود",
    "Searching other places" : "البحث في أماكن أخرى",
    "Personal" : "شخصي",
    "Users" : "المستخدمين",
    "Apps" : "التطبيقات",
    "Admin" : "المدير",
    "Help" : "المساعدة",
    "Access forbidden" : "التوصّل محظور",
    "File not found" : "لم يتم العثور على الملف",
    "Technical details" : "تفاصيل تقنية",
    "Remote Address: %s" : "العنوان البعدي : %s",
    "Type: %s" : "النوع : %s",
    "Code: %s" : "الرمز : %s",
    "Message: %s" : "الرسالة : %s",
    "File: %s" : "ملف : %s",
    "Line: %s" : "السطر: %s",
    "Security warning" : "تحذير الأمان",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "مجلدات البيانات والملفات الخاصة قد تكون قابلة للوصول اليها عن طريق شبكة الانترنت وذلك بسبب ان ملف .htaccess  لا يعمل بشكل صحيح.",
    "Create an <strong>admin account</strong>" : "أضف </strong>مستخدم رئيسي <strong>",
    "Username" : "إسم المستخدم",
    "Storage & database" : "التخزين و قاعدة البيانات",
    "Data folder" : "مجلد المعلومات",
    "Configure the database" : "أسس قاعدة البيانات",
    "Only %s is available." : "لم يتبقى إلّا %s.",
    "For more details check out the documentation." : "للمزيد من التفاصيل، يرجى الإطلاع على الدليل.",
    "Database user" : "مستخدم قاعدة البيانات",
    "Database password" : "كلمة سر مستخدم قاعدة البيانات",
    "Database name" : "إسم قاعدة البيانات",
    "Database tablespace" : "مساحة جدول قاعدة البيانات",
    "Database host" : "خادم قاعدة البيانات",
    "Performance warning" : "تحذير حول الأداء",
    "Finish setup" : "انهاء التعديلات",
    "Finishing …" : "إنهاء …",
    "Need help?" : "محتاج مساعدة؟",
    "See the documentation" : "اطلع على التعليمات",
    "More apps" : "المزيد من التطبيقات",
    "Search" : "البحث",
    "Reset search" : "إعادة تعيين البحث",
    "Confirm your password" : "تأكيد كلمتك السرية",
    "Please contact your administrator." : "يرجى الإتصال بمدير خادومكم.",
    "An internal error occurred." : "طرأ هناك خطأ.",
    "Username or email" : "اسم المستخدم أو البريد الالكتروني",
    "Log in" : "أدخل",
    "Wrong password." : "كلمة السر خاطئة.",
    "Forgot password?" : "هل نسيت كلمة السر ؟",
    "Back to login" : "العودة إلى تسجيل الدخول",
    "Grant access" : "السماح بالنفاذ",
    "Account access" : "حساب النفاذ",
    "Redirecting …" : "عملية التحويل جارية …",
    "New password" : "كلمات سر جديدة",
    "New Password" : "كلمة السر الجديدة",
    "Two-factor authentication" : "المصادقة بخطوتين",
    "Cancel log in" : "إلغاء تسجيل الدخول",
    "Use backup code" : "إستخدم الرمز الإحتياطي",
    "App update required" : "تحديث التطبيق مطلوب",
    "These apps will be updated:" : "سوف يتم تحديث هذه التطبيقات :",
    "Start update" : "تشغيل التحديث",
    "Detailed logs" : "السجلات المفصلة",
    "Update needed" : "التحديث مطلوب",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "للمساعدة يُرجى الإطلاع على <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">الدليل</a>.",
    "Thank you for your patience." : "شكرا لك على صبرك.",
    "There was an error loading your contacts" : "حدث خطأ أثناء تحميل قائمة مراسليك",
    "Shared with {recipients}" : "تمت مشاركته مع {recipients}",
    "This action requires you to confirm your password:" : "يتطلب منك هذا الإجراء تأكيد كلمة المرور :",
    "Wrong password. Reset it?" : "كلمة السر خاطئة. هل تريد إعادة تعيينها ؟",
    "Alternative Logins" : "اسماء دخول بديلة",
    "Add \"%s\" as trusted domain" : "إضافة \"%s\" كنطاق موثوق فيه",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "للمساعدة يُرجى الإطلاع على <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">الدليل</a>.",
    "Back to log in" : "العودة إلى تسجيل الدخول"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-14.0.4.tar.bz2: nextcloud/core/l10n/ar.js <==
OC.L10N.register(
    "core",
    {
    "Please select a file." : "يرجى تحديد ملف.",
    "File is too big" : "الملف كبير جدا",
    "The selected file is not an image." : "الملف المحدد ليس صورة ",
    "The selected file cannot be read." : "الملف المحدد لا يمكن قرأته",
    "Invalid file provided" : "تم تقديم ملف غير صالح",
    "No image or file provided" : "لم يتم توفير صورة أو ملف",
    "Unknown filetype" : "نوع الملف غير معروف",
    "Invalid image" : "الصورة غير صالحة",
    "An error occurred. Please contact your admin." : "حدث خطأ، يرجى مراجعة المسؤول.",
    "No temporary profile picture available, try again" : "لا تتوفر صورة ملف شخصي مؤقتة، حاول مرة أخرى",
    "Crop is not square" : "القص ليس مربعا",
    "Password reset is disabled" : "تم تعطيل إعادة تعيين كلمة المرور",
    "%s password reset" : "%s إعادة تعيين كلمة مرور ",
    "Password reset" : "إعادة تعيين كلمة مرور",
    "Reset your password" : "أعد تعيين كلمة المرور",
    "Couldn't send reset email. Please contact your administrator." : "تعذر إرسال البريد الإلكتروني لإعادة التعيين. يرجى مراجعة المسؤول.",
    "Couldn't send reset email. Please make sure your username is correct." : "تعذر إرسال البريد الإلكتروني لإعادة التعيين. الرجاء التأكد من صحة اسم المستخدم.",
    "Preparing update" : "جارٍ تهيئة التحديث",
    "[%d / %d]: %s" : "[%d/%d]: %s",
    "Repair error: " : "خطأ في الإصلاح:",
    "Turned on maintenance mode" : "تشغيل وضع الصيانة.",
    "Turned off maintenance mode" : "تعطيل وضع الصيانة.",
    "Maintenance mode is kept active" : "لم يزل وضع الصيانة نشط",
    "Updating database schema" : "يحدث مخطط قاعدة البيانات",
    "Updated database" : "قاعدة بيانات محدثة",
    "Checking updates of apps" : "التحقق من تحديثات التطبيقات",
    "Checking for update of app \"%s\" in appstore" : "التحقق من تحديثات التطبيقات \"%s\" في متجر التطبيقات",
    "Update app \"%s\" from appstore" : "قم بتحديث التطبيق \"%s\" عن طريق متجر التطبيقات",
    "Checked for update of app \"%s\" in appstore" : "التحقق من تحديثات التطبيقات \" %s \" في متجر التطبيقات",
    "Updated \"%1$s\" to %2$s" : "حدث \"%1$s\" إلى %2$s",
    "Reset log level" : "أعد تعيين مستوى السجلات",
    "%s (incompatible)" : "%s (غير متوافق)",
    "Already up to date" : "محدّثة مسبقاً",
    "Could not load your contacts" : "تعذر تحميل جهات اتصالاتك",
    "Search contacts …" : "البحث عن مراسلين …",
    "No contacts found" : "لم يعثر على جهات اتصال",
    "Show all contacts …" : "إظهار كافة المراسلين …",
    "Loading your contacts …" : "تحميل جهات الاتصال",
    "Looking for {term} …" : "جاري البحث عن {term}",
    "No action available" : "لا يتوفر أي إجراء",
    "Error fetching contact actions" : "حدث خطأ أثناء جلب إجراءات جهات الاتصال",
    "Settings" : "الضبط",
    "Connection to server lost" : "تم فقد الاتصال بالخادم",
    "Saving..." : "جاري الحفظ...",
    "Dismiss" : "تجاهل",
    "Authentication required" : "المصادقة مطلوبة",
    "This action requires you to confirm your password" : "يتطلب هذا الإجراء منك تأكيد كلمة المرور",
    "Confirm" : "تأكيد",
    "Password" : "كلمة المرور",
    "Failed to authenticate, try again" : "أخفق المصادقة، أعد المحاولة",
    "seconds ago" : "منذ ثواني",
    "Logging in …" : "تسجيل الدخول …",
    "I know what I'm doing" : "أعرف ماذا أفعل",
    "Password can not be changed. Please contact your administrator." : "كلمة المرور لا يمكن تغييرها. فضلاً تحدث مع المسؤول",
    "Reset password" : "تعديل كلمة السر",
    "Sending email …" : "جارٍ إرسال البريد …",
    "No" : "لا",
    "Yes" : "نعم",
    "No files in here" : "لا توجد ملفات هنا",
    "No more subfolders in here" : "لا يوجد هنا ملفات فرعية",
    "Choose" : "اختيار",
    "Copy" : "نسخ",
    "Move" : "نقل",
    "OK" : "موافق",
    "read-only" : "قراءة فقط",
    "_{count} file conflict_::_{count} file conflicts_" : ["لا يوجد تعارض","ملف متعارض","ملفان متعارضان","{count} ملفات متعارضة"," {count} ملفا متعارضا"," {count} ملفا متعارضا"],
    "One file conflict" : "تعارض ملف واحد",
    "New Files" : "ملفات جديدة",
    "Already existing files" : "المفات موجودة مسبقاً",
    "Which files do you want to keep?" : "ماهي الملفات التي ترغب في إبقاءها ؟",
    "If you select both versions, the copied file will have a number added to its name." : "عند إختيار كلا النسختين. المف المنسوخ سيحتوي على رقم في إسمه.",
    "Cancel" : "الغاء",
    "Continue" : "المتابعة",
    "(all selected)" : "(إختيار الكل)",
    "Pending" : "معلّق",
    "Copy to {folder}" : "أنسخ إلى {folder}",
    "Move to {folder}" : "النقل إلى {folder}",
    "New in" : "الجديد في",
    "View changelog" : "اعرض سجل التغييرات",
    "Very weak password" : "كلمة السر ضعيفة جدا",
    "Weak password" : "كلمة السر ضعيفة",
    "Good password" : "كلمة السر جيدة",
    "Strong password" : "كلمة السر قوية",
    "Shared" : "مشارك",
    "Shared with" : "تمت مشاركته مع",
    "Shared by" : "شاركه",
    "Choose a password for the public link" : "اختر كلمة مرور للرابط العام",
    "Choose a password for the public link or press the \"Enter\" key" : "اختر كلمة مرور للرابط العام أو إضغط على زر \"Enter\"",
    "Copied!" : "تم نسخه !",
    "Not supported!" : "غير مدعوم !",
    "Press ⌘-C to copy." : "إضغط C-⌘ للنسخ.",
    "Press Ctrl-C to copy." : "للنسخ إضغط على CTRL+C.",
    "Resharing is not allowed" : "لا يسمح بعملية إعادة المشاركة",
    "Share to {name}" : "تمت مشاركته مع {name}",
    "Link" : "الرابط",
    "Password protect" : "حماية كلمة السر",
    "Allow editing" : "السماح بالتعديلات",
    "Email link to person" : "ارسل الرابط بالبريد الى صديق",
    "Send" : "أرسل",
    "Allow upload and editing" : "السماح بالرفع و التعديل",
    "Read only" : "القراءة فقط",
    "Set expiration date" : "تعيين تاريخ إنتهاء الصلاحية",
    "Expiration" : "إنتهاء",
    "Expiration date" : "تاريخ إنتهاء الصلاحية",
    "Unshare" : "إلغاء مشاركة",
    "Share link" : "شارك الرابط",
    "Could not unshare" : "لا يمكن إلغاء المشاركة",
    "Shared with you and the group {group} by {owner}" : "شورك معك ومع المجموعة {group} من قبل {owner}",
    "Shared with you by {owner}" : "شورك معك من قبل {owner}",
    "Choose a password for the mail share" : "إختر كلمة سرية للمشاركة عبر البريد الإلكتروني",
    "group" : "مجموعة",
    "remote" : "عن بعد",
    "email" : "البريد الإلكتروني",
    "shared by {sharer}" : "شارَكه {sharer}",
    "Can reshare" : "يمكنه إعادة المشاركة",
    "Can edit" : "يمكنه التغيير",
    "Can create" : "يمكنه الإنشاء",
    "Can change" : "يمكنه تعديله",
    "Can delete" : "يمكنه الحذف",
    "Access control" : "مراقبة النفاذ",
    "Error while sharing" : "حصل خطأ عند عملية المشاركة",
    "An error occurred. Please try again" : "طرأ هناك خطأ. الرجاء إعادة المحاولة",
    "Share" : "شارك",
    "Name or email address..." : "الإسم أو عنوان البريد الإلكتروني …",
    "Name or federated cloud ID..." : "الإسم أو معرّف السحابة المتحدة …",
    "Name..." : "التسمية …",
    "Error" : "خطأ",
    "restricted" : "مُقيَّد",
    "invisible" : "مخفي",
    "({scope})" : "({scope})",
    "Delete" : "إلغاء",
    "Rename" : "إعادة التسمية",
    "No tags found" : "لم يُعثَر على أي وسم",
    "unknown text" : "النص غير معروف",
    "Hello world!" : "مرحبا بالعالم!",
    "sunny" : "مشمس",
    "Hello {name}" : "مرحبا {name}",
    "new" : "جديد",
    "_download %n file_::_download %n files_" : ["تنزيل %n ملف","تنزيل ملف واحد","تنزيل ملفين","تنزيل %n ملفات","تنزيل %n ملفات","تنزيل %n ملفات"],
    "Update to {version}" : "التحديث إلى {version}",
    "An error occurred." : "طرأ هناك خطأ.",
    "Please reload the page." : "رجاء أعد تحميل الصفحة.",
    "Continue to Nextcloud" : "المواصلة إلى ناكست كلاود",
    "Searching other places" : "البحث في أماكن أخرى",
    "Personal" : "شخصي",
    "Users" : "المستخدمين",
    "Apps" : "التطبيقات",
    "Admin" : "المدير",
    "Help" : "المساعدة",
    "Access forbidden" : "التوصّل محظور",
    "File not found" : "لم يتم العثور على الملف",
    "Technical details" : "تفاصيل تقنية",
    "Remote Address: %s" : "العنوان البعدي : %s",
    "Type: %s" : "النوع : %s",
    "Code: %s" : "الرمز : %s",
    "Message: %s" : "الرسالة : %s",
    "File: %s" : "ملف : %s",
    "Line: %s" : "السطر: %s",
    "Security warning" : "تحذير الأمان",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "مجلدات البيانات والملفات الخاصة قد تكون قابلة للوصول اليها عن طريق شبكة الانترنت وذلك بسبب ان ملف .htaccess  لا يعمل بشكل صحيح.",
    "Create an <strong>admin account</strong>" : "أضف </strong>مستخدم رئيسي <strong>",
    "Username" : "إسم المستخدم",
    "Storage & database" : "التخزين و قاعدة البيانات",
    "Data folder" : "مجلد المعلومات",
    "Configure the database" : "أسس قاعدة البيانات",
    "Only %s is available." : "لم يتبقى إلّا %s.",
    "For more details check out the documentation." : "للمزيد من التفاصيل، يرجى الإطلاع على الدليل.",
    "Database user" : "مستخدم قاعدة البيانات",
    "Database password" : "كلمة سر مستخدم قاعدة البيانات",
    "Database name" : "إسم قاعدة البيانات",
    "Database tablespace" : "مساحة جدول قاعدة البيانات",
    "Database host" : "خادم قاعدة البيانات",
    "Performance warning" : "تحذير حول الأداء",
    "Finish setup" : "انهاء التعديلات",
    "Finishing …" : "إنهاء …",
    "Need help?" : "محتاج مساعدة؟",
    "See the documentation" : "اطلع على التعليمات",
    "More apps" : "المزيد من التطبيقات",
    "Search" : "البحث",
    "Reset search" : "إعادة تعيين البحث",
    "Confirm your password" : "تأكيد كلمتك السرية",
    "Please contact your administrator." : "يرجى الإتصال بمدير خادومكم.",
    "An internal error occurred." : "طرأ هناك خطأ.",
    "Username or email" : "اسم المستخدم أو البريد الالكتروني",
    "Log in" : "أدخل",
    "Wrong password." : "كلمة السر خاطئة.",
    "Forgot password?" : "هل نسيت كلمة السر ؟",
    "Back to login" : "العودة إلى تسجيل الدخول",
    "Grant access" : "السماح بالنفاذ",
    "Account access" : "حساب النفاذ",
    "Redirecting …" : "عملية التحويل جارية …",
    "New password" : "كلمات سر جديدة",
    "New Password" : "كلمة السر الجديدة",
    "Two-factor authentication" : "المصادقة بخطوتين",
    "Use backup code" : "إستخدم الرمز الإحتياطي",
    "Cancel log in" : "إلغاء تسجيل الدخول",
    "App update required" : "تحديث التطبيق مطلوب",
    "These apps will be updated:" : "سوف يتم تحديث هذه التطبيقات :",
    "Start update" : "تشغيل التحديث",
    "Detailed logs" : "السجلات المفصلة",
    "Update needed" : "التحديث مطلوب",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "للمساعدة يُرجى الإطلاع على <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">الدليل</a>.",
    "There was an error loading your contacts" : "حدث خطأ أثناء تحميل قائمة مراسليك",
    "Shared with {recipients}" : "تمت مشاركته مع {recipients}",
    "Error setting expiration date" : "حصل خطأ عند عملية تعيين تاريخ إنتهاء الصلاحية",
    "{sharee} (group)" : "{sharee} (group)",
    "{sharee} (remote)" : "{sharee} (remote)",
    "{sharee} (email)" : "{sharee} (email)",
    "This action requires you to confirm your password:" : "يتطلب منك هذا الإجراء تأكيد كلمة المرور :",
    "Wrong password. Reset it?" : "كلمة السر خاطئة. هل تريد إعادة تعيينها ؟",
    "Alternative Logins" : "اسماء دخول بديلة",
    "Add \"%s\" as trusted domain" : "إضافة \"%s\" كنطاق موثوق فيه",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "للمساعدة يُرجى الإطلاع على <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">الدليل</a>.",
    "Thank you for your patience." : "شكرا لك على صبرك.",
    "Back to log in" : "العودة إلى تسجيل الدخول"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
